# Zephyr

[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/uwoseis/zephyr/blob/master/LICENSE)
[![Travis Status](https://travis-ci.org/uwoseis/zephyr.svg?branch=master)](https://travis-ci.org/uwoseis/zephyr)
[![Coverage Status](https://coveralls.io/repos/uwoseis/zephyr/badge.svg?branch=master&service=github)](https://coveralls.io/github/uwoseis/zephyr?branch=master)
[![Code Issues](https://www.quantifiedcode.com/api/v1/project/02a2dbe184e04d1482daa174e9973501/badge.svg)](https://www.quantifiedcode.com/app/project/02a2dbe184e04d1482daa174e9973501)

Open-source seismic waveform modelling and inversion code written in Python

- Project site: [https://zephyr.space](https://zephyr.space)
- Auto docs: [https://zephyr.space/api/zephyr.html](https://zephyr.space/api/zephyr.html)

## Authors

- Brendan Smithyman <[brendan@bitsmithy.net](mailto:brendan@bitsmithy.net)>
- Shaun Hadden <[shadden2@uwo.ca](mailto:shadden2@uwo.ca)>
